@@ -192,7 +192,7 @@ class teg:
                         elif yee[i][1] == "NNPS":
                             nnpsn = [
                                 "LIGHT neRs",
-                                "DARK nERs",
+                                "DARK neRs",
                                 "[Friends]",
                                 "[[Hearts]]"
                             ]
@@ -209,8 +209,9 @@ class teg:
                         elif yee[i][1] == "NNP":
                             nnpn = [
                                 "Kris",
-                                "Salesman1997"
-                                "Little Sponge"
+                                "Salesman1997",
+                                "Little Sponge",
+                                "[[Hyperlink Blocked]]"
                             ]
                             dumb2 = random.choice(nnpn)
                             dumb2_1 = random.randint(0, 1)
@@ -244,5 +245,38 @@ class teg:
         except NameError:
             raise ModuleError("nltk must be installed to use beetroot.text.spamton(). Try pip install nltk or pip install beetroot[text].")
             
+    def greek(self, text):
+        greekalpha = list(str("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyzΑΒΨΔΕΦΓΗΙΞΚΛΜΝΟΠ:ΡΣΤΘΩ΅ΧΥΖαβψδεφγηιξκλμνοπ;ρστθωςχυζABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyzΑΒΨΔΕΦΓΗΙΞΚΛΜΝΟΠ:ΡΣΤΘΩ΅ΧΥΖαβψδεφγηιξκλμνοπ;ρστθωςχυζ"))
+        
+        text = list(self._objreplic(self._objreplic(str(text), "greek", "Ellihnika"), "english", "Agglika"))
+        #print(text)
+        for i in range(0, len(text)):
+            try:
+                spos = greekalpha.index(text[i])
+                text[i] = greekalpha[spos + 52]
+                
+            except (ValueError, IndexError):
+                pass
+            
+        return "".join(text)
+    
+    def russian(self, text):
+        rusalpha = list(str("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyzФИСВУАПРШОЛДЬТЩЗЙКЫЕГМЦЧНЯфисвуапршолдьтщзйкыегмцчняABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyzФИСВУАПРШОЛДЬТЩЗЙКЫЕГМЦЧНЯфисвуапршолдьтщзйкыегмцчня"))
+        
+        text = list(self._objreplic(self._objreplic(str(text), "russian", "Heccrqq"), "english", "Ayukqqcrqq"))
+        #print(text)
+        for i in range(0, len(text)):
+            try:
+                spos = rusalpha.index(text[i])
+                text[i] = rusalpha[spos + 52]
+                
+            except (ValueError, IndexError):
+                pass
+            
+        return "".join(text)
+    
+    def reverse(self, text):
+        return str(text)[::-1]
+                    
 text = teg()
 del teg
\ No newline at end of file
